Module process

Module process 

Process execution and output handling.

Structs

ProcessOutput
Represents the output of a process.

Functions

execute_command
Executes a command with the given arguments and timeout.
execute_command_to_file
Executes a command and redirects stdout to a file.