Format

Struct Format 

pub struct Format {
Show 18 fields pub format: String, pub format_id: String, pub format_note: Option<String>, pub protocol: Protocol, pub language: Option<String>, pub has_drm: Option<DrmStatus>, pub container: Option<Container>, pub available_at: Option<i64>, pub language_preference: Option<i64>, pub source_preference: Option<i64>, pub codec_info: CodecInfo, pub video_resolution: VideoResolution, pub download_info: DownloadInfo, pub quality_info: QualityInfo, pub file_info: FileInfo, pub storyboard_info: StoryboardInfo, pub rates_info: RatesInfo, pub video_id: Option<String>,
}
Represents an available format of a video. It can be audio, video, both of them, a manifest, or a storyboard.

A manifest is a file that contains metadata about the video streams, and how to assemble them. A storyboard is a file that contains grid of images from the video, allowing users to preview the video. Usually, these formats are not meant to be downloaded, but to be used by the player. So, in most cases, you can ignore them.

Fields

format: String

The display name of the format, e.g. ‘303 - 1920x1080 (1080p60)’.

format_id: String

The format ID, e.g. ‘303’.

format_note: Option<String>

The format note, e.g. ‘1080p60’.

protocol: Protocol

The type of the format.

language: Option<String>

The language of the format.

has_drm: Option<DrmStatus>

If the format has DRM.

container: Option<Container>

The extension of the file containing the format.

available_at: Option<i64>

The Unix timestamp when this format’s stream URL became available (yt-dlp fetch time). Used to detect CDN URL expiry: YouTube URLs typically last ~6 hours after this timestamp.

language_preference: Option<i64>

yt-dlp internal language preference score for this format.

source_preference: Option<i64>

yt-dlp internal source preference score for this format.

codec_info: CodecInfo

All the codec-related information.

video_resolution: VideoResolution

All the video resolution-related information.

download_info: DownloadInfo

All the download-related information.

quality_info: QualityInfo

All the quality-related information.

file_info: FileInfo

All the file-related information.

storyboard_info: StoryboardInfo

All the storyboard-related information.

rates_info: RatesInfo

All the rates-related information.

video_id: Option<String>

The ID of the video this format belongs to. This field is not part of the yt-dlp output, but is added by the library to associate formats with their videos for caching purposes.

Implementations

Source

impl Format

pub fn is_video(&self) -> bool

Checks if the format is a video format.

pub fn is_audio(&self) -> bool

Checks if the format is an audio format.

pub fn format_type(&self) -> FormatType

Gets the type of the format. It can be audio, video, both of them, a manifest, or a storyboard.

Returns

The FormatType determined from the codec and manifest information.

pub fn url(&self) -> Result<&String, Error>

Returns the decrypted URL for this format.

Errors

Returns Error::FormatNoUrl if the format has no URL.

Returns

A reference to the format URL string.