pub enum PersistentFileBackend {
Redb(RedbFileCache),
}Expand description
Enum dispatch for persistent file backends.
Variants
Redb(RedbFileCache)
Implementations
Sourceimpl PersistentFileBackend
impl PersistentFileBackend
Sourcepub async fn new(config: &CacheConfig, ttl: Option<u64>) -> Result<Self>
pub async fn new(config: &CacheConfig, ttl: Option<u64>) -> Result<Self>
Creates the persistent file backend for the selected kind.
Arguments
config- The cache configuration specifying directories, TTLs, and backend settings.ttl- Time-to-live in seconds
Errors
Returns Error::AmbiguousCacheBackend if kind is None and multiple backends are compiled in.
Returns an error if the selected backend fails to initialize.