pub enum PersistentVideoBackend {
Redb(RedbVideoCache),
}Expand description
Enum dispatch for persistent video backends.
All features’ variants are included when their respective feature is enabled.
The active backend is selected at construction time via PersistentBackendKind::resolve.
Variants
Redb(RedbVideoCache)
Implementations
Sourceimpl PersistentVideoBackend
impl PersistentVideoBackend
Sourcepub async fn new(config: &CacheConfig, ttl: Option<u64>) -> Result<Self>
pub async fn new(config: &CacheConfig, ttl: Option<u64>) -> Result<Self>
Creates the persistent video backend for the selected kind.
Arguments
config- The cache configuration specifying directories, TTLs, and backend settings.ttl- Time-to-live in seconds
Errors
Returns Error::AmbiguousCacheBackend if kind is None and multiple backends are compiled in.
Returns an error if the selected backend fails to initialize.