Process execution and output handling.
Structs
- Process
Output - Represents the output of a process.
Functions
- execute_
command - Executes a command with the given arguments and timeout.
- execute_
command_ to_ file - Executes a command and redirects stdout to a file.