pub struct Executor { /* private fields */ }Expand description
Represents a command executor.
Example
let args = vec!["--update"];
let executor = Executor::new(
PathBuf::from("yt-dlp"),
utils::to_owned(args),
Duration::from_secs(30),
);
let output = executor.execute().await?;
println!("Output: {}", output.stdout);
Implementations
Sourceimpl Executor
impl Executor
Sourcepub fn executable_path(&self) -> &PathBuf
pub fn executable_path(&self) -> &PathBuf
Sourcepub async fn execute(&self) -> Result<ProcessOutput>
pub async fn execute(&self) -> Result<ProcessOutput>
Sourcepub async fn execute_to_file(
&self,
output_path: impl Into<PathBuf>,
) -> Result<ProcessOutput>
pub async fn execute_to_file( &self, output_path: impl Into<PathBuf>, ) -> Result<ProcessOutput>
Executes the command and redirects stdout to a file.
Arguments
output_path- The path where stdout will be written
Returns
ProcessOutput containing stderr and exit code (stdout is written to file)
Errors
This function will return an error if the command could not be executed, if the process timed out, or if the output file could not be created.
Sourcepub async fn execute_streaming(&self) -> Result<StreamingProcess>
pub async fn execute_streaming(&self) -> Result<StreamingProcess>
Spawns the command as a long-running process without timeout.
Returns a StreamingProcess handle that can be stopped gracefully
via stdin q (for FFmpeg) or killed. Intended for live recording.
Errors
Returns an error if the process could not be spawned.